"""Product type for a Layer 2 circuit."""

from orchestrator.domain.base import SubscriptionModel
from orchestrator.types import SubscriptionLifecycle
from pydantic_forms.types import strEnum

from gso.products.product_blocks.layer_2_circuit import (
    Layer2CircuitBlock,
    Layer2CircuitBlockInactive,
    Layer2CircuitBlockProvisioning,
)


class Layer2CircuitServiceType(strEnum):
    """Available types of Layer 2 Circuit services."""

    GEANT_PLUS = "GÉANT Plus"
    IMPORTED_GEANT_PLUS = "Imported GÉANT Plus"
    EXPRESSROUTE = "Azure ExpressRoute"
    IMPORTED_EXPRESSROUTE = "Imported Azure ExpressRoute"


class Layer2CircuitInactive(SubscriptionModel, is_base=True):
    """An inactive Layer 2 Circuit."""

    layer_2_circuit_service_type: Layer2CircuitServiceType
    layer_2_circuit: Layer2CircuitBlockInactive


class Layer2CircuitProvisioning(Layer2CircuitInactive, lifecycle=[SubscriptionLifecycle.PROVISIONING]):
    """A Layer 2 Circuit that is provisioning."""

    layer_2_circuit_service_type: Layer2CircuitServiceType
    layer_2_circuit: Layer2CircuitBlockProvisioning


class Layer2Circuit(Layer2CircuitProvisioning, lifecycle=[SubscriptionLifecycle.ACTIVE]):
    """An active Layer 2 Circuit."""

    layer_2_circuit_service_type: Layer2CircuitServiceType
    layer_2_circuit: Layer2CircuitBlock


class ImportedLayer2CircuitInactive(SubscriptionModel, is_base=True):
    """An imported, inactive Layer 2 Circuit."""

    layer_2_circuit_service_type: Layer2CircuitServiceType
    layer_2_circuit: Layer2CircuitBlockInactive


class ImportedLayer2Circuit(
    ImportedLayer2CircuitInactive, lifecycle=[SubscriptionLifecycle.PROVISIONING, SubscriptionLifecycle.ACTIVE]
):
    """An imported Layer 2 Circuit."""

    layer_2_circuit_service_type: Layer2CircuitServiceType
    layer_2_circuit: Layer2CircuitBlock
